ServiceRegistration

Struct ServiceRegistration 

pub struct ServiceRegistration { /* private fields */ }
Reference to a registered service instance.

The service will be automatically unregistered when this value is dropped.

Implementations

Source

impl ServiceRegistration

pub async fn unregister(self) -> Result<(), String>

Unregisters the service, notifying remote clients that the service is no longer available.

Use this method instead of dropping the ServiceRegistration if you want to be notified of any errors that occur during unregistration.